@@ -1,9 +1,9 @@
 /*
  * i18n.c -
- * $Id: i18n.c,v 1.26.4.4 2001/12/21 05:36:40 knok Exp $
+ * $Id: i18n.c,v 1.26.4.7 2004/03/20 15:25:09 usu Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000,2001 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2003 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -121,8 +121,10 @@ nmz_set_lang(const char *lang)
 #else
 # ifdef HAVE_PUTENV
 	{
-	    static char *store;
+	    static char *store = NULL;
 
+	    if (store != NULL)
+		free(store);
 	    store = (char *)malloc(strlen(lang) + 6); /* do *not* free */
 	    if (store == NULL)
 		return NULL; /* FIXME: should be fatal error */
@@ -163,7 +165,7 @@ nmz_choose_msgfile_suffix(const char *pfname,  char *lang_suffix)
 {
     FILE *fp;
     int baselen;
-    char fname[BUFSIZE];
+    char fname[BUFSIZE] = "";
 
     strncpy(fname, pfname, BUFSIZE - 1);
     baselen = strlen(fname);
