@@ -2,10 +2,10 @@
  * 
  * form.c -
  * 
- * $Id: form.c,v 1.60.4.8 2001/12/21 03:30:24 knok Exp $
+ * $Id: form.c,v 1.60.4.14 2004/03/20 15:02:51 usu Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2004 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,9 @@
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
+#ifdef HAVE_SUPPORT_H
+#  include "support.h"
+#endif
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -184,7 +187,7 @@ get_select_name(const char *s, char *value)
 static enum nmz_stat
 select_option(char *s, const char *name, const char *subquery)
 {
-    char value[BUFSIZE];
+    char value[BUFSIZE] = "";
 
     if (cmp_element(s, (char *)"option") == 0) {
 	if(strcmp(nmz_getenv("QUERY_STRING"), "")) {
@@ -216,7 +219,7 @@ select_option(char *s, const char *name, const char *subquery)
 	    {
 		char *p;
 		int n, order = DESCENDING;
-		char field[BUFSIZE];
+		char field[BUFSIZE] = "";
 
 		p = value + strlen("field:");
 		n = strspn(p, FIELD_SAFE_CHARS);
@@ -266,7 +269,7 @@ select_option(char *s, const char *name, const char *subquery)
 static enum nmz_stat
 check_checkbox(char *str)
 {
-    char value[BUFSIZE];
+    char value[BUFSIZE] = "";
     int i;
 
     if (cmp_element(str, "input type=\"checkbox\" name=\"idxname\"") == 0) {
@@ -279,7 +282,7 @@ check_checkbox(char *str)
         fputs(str, stdout);
         get_value(str, value);
         for (pp = value, db_count = searched = 0 ; *pp ;db_count++) {
-            char name[BUFSIZE], *x;
+            char name[BUFSIZE] = "", *x;
             if ((x = (char *)strchr(pp, (int)','))) {
                 *x = '\0';
                 strncpy(name, pp, BUFSIZE - 1);
@@ -313,7 +316,7 @@ static void
 handle_tag(const char *start, const char *end, const char *query, 
                char *select_name, const char *subquery)
 {
-    char tmp[BUFSIZE];
+    char tmp[BUFSIZE] = "";
     int l;
 
     l = end - start + 1;
@@ -327,14 +330,16 @@ handle_tag(const char *start, const char *end, const char *query,
         if (check_checkbox(tmp) == SUCCESS)
             return;
         get_select_name(tmp, select_name);
+	fputs(tmp, stdout);
+    } else {
+	fprintf(stdout, "%*.*s", l, l, start);
     }
-    fputs(tmp, stdout);
 }
 
 static char *
 read_headfoot(const char *fname) 
 {
-    char *buf, *p, tmpfname[BUFSIZE], suffix[BUFSIZE];
+    char *buf, *p, tmpfname[BUFSIZE] = "", suffix[BUFSIZE] = "";
     char *script_name;
     char *document_name;
 
@@ -475,8 +480,13 @@ print_headfoot(const char * fname, const char * query, const char *subquery)
 	     */
             q = (char *)strchr(p, (int)'>');
             fputs("<", stdout);
-            handle_tag(p + 1, q - 1, query, name, subquery);
-            fputs(">", stdout);
+	    if (*(q-1) != '/') {
+		handle_tag(p + 1, q - 1, query, name, subquery);
+		fputs(">", stdout);
+	    } else {            /* for XHTML */
+		handle_tag(p + 1, q - 2, query, name, subquery);
+		fputs("/>", stdout);
+	    }
             p = q;
         } else {
             if ((strncmp(p, "\033$", 2) == 0)
